****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_qrpe_loopmeds.sas  
*
* Created (mm/dd/yyyy): 03/01/2018
* Last modified:
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
* 	This program will extract claims using code CodeType CodeCat EncType Pdx and Padmit.  This 
*  	macro is very similar to ms_extractmeds.  For clarity purpose and because of the 
*  	wildcards handle for EncType and Pdx, both macros were kept as separate macros.
*
*  Program inputs:                                                                                   
* 	-dataset containing the raw claims  
*	-dataset containing the lookup parameters
* 
*  Program outputs:                                                                                                                                                            
*	-dataset with the extracted claims
*
* PARAMETERS:
*	-datafile	= Name of the dataset containing the raw claims 
*   -lookfile	= Name of the dataset containing the lookup parameters
*   -outfile	= Name of the dataset with the extracted claims 
*
*  Programming Notes:                                                                                
*  	-This loop meds will support wildcard for Caresetting and Principal as created 
*    by the macro ms_caresettingprincipal  
*	-This loop meds will support wildcard for Padmit as created by the macro ms_padmit 
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials	   Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*
***************************************************************************************************;

%MACRO ms_qrpe_loopmeds(datafile=, lookfile=, outfile=);

    %put =====> MACRO CALLED: ms_qrpe_loopmeds v1.0;

    %ISDATA(dataset=&lookfile.);

	%IF %EVAL(&NOBS.>=1) %THEN %DO;
      
        proc sql noprint;
        create table &outfile.(drop=enctype) as
        select claim.PatId,
			   claim.encounterID,
               claim.Adate length 4 format date9.,
               Codes.*
        from &datafile. as claim,
             &lookfile. as codes
        where upcase(codes.code)     = upcase(claim.code) and
              codes.CodeType = claim.CodeType and 
              codes.CodeCat  = claim.CodeCat and 
              ((codes.EncType = claim.EncType and codes.Pdx = claim.Pdx) or  /*No Wilcards*/
               (codes.EncType = "**"          and codes.Pdx = claim.Pdx) or  /*Any EncType*/
               (codes.EncType = claim.EncType and codes.Pdx = "*") or        /*Any Pdx*/
               (codes.EncType = "**"          and codes.Pdx = "*")) and
			  ((codes.Padmit = claim.padmit) or codes.padmit= "*");
        quit;
    %END;
    %ELSE %DO;
        data &outfile.(drop=enctype);
        length codetype $3. padmit $1.;
        set &datafile.(obs=0) &lookfile.(obs=0 drop=code);
        run;
    %END;

    %put NOTE: ********END OF MACRO: ms_qrpe_loopmeds v1.0********;

%MEND ms_qrpe_loopmeds;       
